package cz.muni.fi.pa165.movie;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.List;

@Controller
@RestController
@RequestMapping("/movies")
public class MovieController {

    private final MovieService movieService;

    @Autowired
    public MovieController(MovieService movieService) {
        this.movieService = movieService;
    }

    @GetMapping
    public List<MovieDto> getMovies() {
        return movieService.getMovies();
    }

    @GetMapping("{id}")
    public MovieDto getMovie(@PathVariable long id) {
        return movieService.getMovie(id);
    }

    @PostMapping
    public void createMovie(@Valid @RequestBody MovieDto movieDto) {
        movieService.createMovie(movieDto);
    }

    @PostMapping("{id}")
    public void updateMovie(@PathVariable long id, @Valid @RequestBody MovieDto movieDto) {
        movieService.updateMovie(id, movieDto);
    }

    @DeleteMapping("{id}")
    public void deleteMovie(@PathVariable long id) {
        movieService.deleteMovie(id);
    }

    @DeleteMapping
    public void deleteAllMovies() {
        movieService.deleteAllMovies();
    }

    @GetMapping("/title/{title}")
    public MovieDto findByTitle(@PathVariable String title) {
        return movieService.findByTitle(title);
    }
}
