package cz.muni.fi.pa165;

import cz.muni.fi.pa165.movie.GenreEnum;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpHeaders;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.io.IOException;


@RestController
@RequestMapping("/recommender")
public class ReportController {

    private final ReportService reportService;

    @Autowired
    public ReportController(ReportService reportService) {
        this.reportService = reportService;
    }

    @GetMapping(produces = MediaType.TEXT_PLAIN_VALUE)
    public ResponseEntity<byte[]> getMoviesWithAverageRating() throws IOException {
        String fileName = "best-movies.txt";
        byte[] file = reportService.getMoviesWithAverageRating(fileName);
        return file == null ? null : getResponseEntity(fileName, file);
    }

    @GetMapping(value = "{genre}", produces = MediaType.TEXT_PLAIN_VALUE)
    public ResponseEntity<byte[]> getMoviesWithAverageRatingByGenre(@PathVariable GenreEnum genre) throws IOException {
        String fileName = "best-movies-" + genre + ".txt";
        byte[] file = reportService.getMoviesWithAverageRatingByGenre(genre, fileName);
        return file == null ? null : getResponseEntity(fileName, file);
    }

    private ResponseEntity<byte[]> getResponseEntity(String fileName, byte[] file) {
        HttpHeaders headers = new HttpHeaders();
        headers.set(HttpHeaders.CONTENT_TYPE, MediaType.TEXT_PLAIN_VALUE);
        headers.set(HttpHeaders.CONTENT_DISPOSITION, "attachment; filename=" + fileName);
        headers.set(HttpHeaders.CACHE_CONTROL, "must-revalidate, post-check=0, pre-check=0");
        headers.set(HttpHeaders.PRAGMA, "public");
        headers.set(HttpHeaders.EXPIRES, "0");
        headers.setContentLength(file.length);
        return new ResponseEntity<>(file, headers, HttpStatus.OK);
    }
}
